@@ -88,7 +88,7 @@ class OAuth2Session(aiohttp.ClientSession):
 
         # Ensure that requests doesn't do any automatic auth. See #278.
         # The default behavior can be re-enabled by setting auth to None.
-        self.auth = lambda r: r
+        # self._default_auth = lambda r: r
 
         # Allow customizations for non compliant providers through various
         # hooks to adjust requests and responses.
@@ -434,7 +434,6 @@ class OAuth2Session(aiohttp.ClientSession):
             timeout=timeout,
             headers=headers,
             verify_ssl=verify_ssl,
-            withhold_token=True,
             proxy=proxy,
         ) as r:
             text = await r.text()
